# Installation

## Stable release

To install Python Boilerplate, run this command in your terminal:

```sh
uv add django-msteams-notify
```

Or if you prefer to use `pip`:

```sh
pip install django-msteams-notify
```

## From source

The source files for Python Boilerplate can be downloaded from the [Github repo](https://github.com/audreyfeldroy/django_msteams_notify).

You can either clone the public repository:

```sh
git clone git://github.com/audreyfeldroy/django_msteams_notify
```

Or download the [tarball](https://github.com/audreyfeldroy/django_msteams_notify/tarball/master):

```sh
curl -OJL https://github.com/audreyfeldroy/django_msteams_notify/tarball/master
```

Once you have a copy of the source, you can install it with:

```sh
cd django_msteams_notify
uv pip install .
```
